import subprocess
import pygit2
import json

class Generic():
    def __init__(self, file):
        self.file = file

    def operate(self):
        with open(self.file) as f:
            _data = f.read()
            if "source" in json.loads(_data):
                for cmd in json.loads(_data)["source"]:
                    if "link" in cmd:
                        pygit2.clone_repository(cmd["link"], str(cmd["link"].rsplit('/', 1).pop()))
                    if "cmds" in cmd:
                            cmds = cmd["cmds"]
                            for x in cmds:
                                if "cmd" in x:
                                    if "dir" in x:
                                        subprocess.call(x["cmd"].split(), cwd=x["dir"])
                                    else:
                                        subprocess.call(x["cmd"].split())



from setuptools import setup, find_packages
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
with open("requirements.txt", "r", encoding="utf-8") as fh:
    requirements = fh.read()
setup(
    name = 'niagara',
    version = '0.0.0.2',
    author = 'kavulox',
    license = 'AGPL-3.0',
    description = 'A simple ricing tool for Linux systems.',
    long_description = long_description,
    long_description_content_type = "text/markdown",
    url = 'https://github.com/ArtixLabs/Niagara',
    py_modules = ['niagara'],
    packages = find_packages(),
    install_requires = [requirements],
    python_requires='>=3.9',
    classifiers=[
        "Programming Language :: Python :: 3.9"
    ],
    entry_points = '''
        [console_scripts]
        niagara=niagara.__main__:run
    '''
)



import argparse
from .config import Config
from .generic import Generic
from .packages import Packages
parser = argparse.ArgumentParser()
VERSION="0.0.0.2"
parser.add_argument('-c','--config')
parser.add_argument('-p', '--packages')
parser.add_argument('--set-os')
parser.add_argument('-d', '--dry')
parser.add_argument('-v', '--version', action="store_true")
args = parser.parse_args()
def run():
    if args.set_os:
        arch = args.set_os
    else:
        arch = 'arch'
    if args.dry:
        x = Packages()
        x.dry_run(args.dry, arch)
    if args.version == True:
        print(VERSION)
    if args.packages:
        x = Packages()
        x.dump_all_pkgs(args.packages)
    if args.config:
        x = Packages()
        x.install_pkgs(args.config)
        v = Config(args.config)
        v.operate()
        x = Generic(args.config)
        x.operate()







import os
import subprocess
from urllib.request import urlretrieve
import json
import pygit2


class Config():
    def __init__(self, file):
        self.file = file

    def operate(self):
        with open(self.file) as f:
            _data = f.read()
            _json_data = json.loads(_data)
            if "config" in _json_data:
                _config_opts = _json_data["config"]
                for opt in _config_opts:
                    if opt.get("option") == "wallpaper": # ADD DEP CHECK FOR PKGS
                        file = str(opt.get("val").rsplit('/', 1).pop())
                        if os.path.exists(os.environ['HOME'] + '/.wallpaper'):
                            urlretrieve(str(opt.get("val")), file)
                            os.replace(file, os.environ['HOME'] + '/.wallpaper/' + file)
                        else:
                            os.mkdir(os.environ['HOME'] + '/.wallpaper')
                            urlretrieve(str(opt.get("val")), file)
                            os.replace(file, os.environ['HOME'] + '/.wallpaper/' + file)
                        subprocess.call(['feh', '--bg-scale', os.environ['HOME'] + '/.wallpaper/' + file])
                    elif opt.get("option") == "dotfile":
                        for x in opt.get("val"):
                            pygit2.clone_repository(x, os.environ['HOME'] + '/.config/' + str(x.rsplit('/', 1).pop()))
                    elif opt.get("option") == "scripts":
                        for script in opt.get("val"):
                            if script.get("method"):
                                method = script.get("method")
                            else:
                                method = "git"
                            if method == "curl":
                                print(script.get("url"))
                                urlretrieve(str(script.get("url")), str(script.get("url").rsplit('/', 1).pop()))
                                subprocess.call(['sh', str(script.get("url").rsplit('/', 1).pop())])
                            elif method == "git":
                                pygit2.clone_repository(script.get("url"), str(script.get("url").rsplit('/', 1).pop()))
                                if script.get("trigger"):
                                    subprocess.call(script.get("trigger").split())
                                else:
                                    subprocess.call(['sh', script.get("url") + '/' + 'script.sh'])

